import os
import shutil
import time
from aria2p import API, Client


class Aria2Monitor:
    def __init__(self, aria2_rpc_url, aria2_rpc_secret=None):
        self.aria2_client = Client(aria2_rpc_url, secret=aria2_rpc_secret)
        self.aria2_api = API(self.aria2_client)


    def monitor_and_move_shutil(self, source_folder, destination_folder, check_interval=10):
        while True:
            downloads = self.aria2_api.get_downloads()
            for download in downloads:
                if download.is_complete:
                    all_files_moved = True
                    for file in download.files:
                        if file.selected:
                            file_name = os.path.basename(file.path)
                            source_path = os.path.join(source_folder, file_name)  # 使用传入的源目录地址
                            target_path = os.path.join(destination_folder, file_name)
                            print(f"Prepare to move: {source_path} -> {target_path}")

                            try:
                                if os.path.exists(source_path):
                                    shutil.move(source_path, target_path)
                                    print(f"Successfully moved: {source_path} -> {target_path}")
                                else:
                                    print(f"File not found: {source_path}")
                                    all_files_moved = False
                            except Exception as e:
                                print(f"Error moving file: {e}")
                                all_files_moved = False

                    # 仅在所有文件都成功移动后删除记录
                    if all_files_moved:
                        download.remove()

            time.sleep(check_interval)



if __name__ == '__main__':
    # 使用示例
    aria2_monitor = Aria2Monitor("http://192.168.88.10", "123456")
    source_folder = "/mnt/data1/download/moive"
    destination_folder = "/mnt/video/sync/movie"
    aria2_monitor.monitor_and_move_shutil(destination_folder)
